@@ -12,19 +12,6 @@
 #'
 #'   Get started by reading \code{vignette("datefixR")}
 #'
-#' @section Author:
-#' \strong{Maintainer}: Nathan Constantine-Cooke
-#' \email{nathan.constantine-cooke@@ed.ac.uk}
-#' \href{https://orcid.org/0000-0002-4437-8713}{(ORCID)}
-#'
-#' Other contributors:
-#'  * Jonathan Kitt `[`contributor, translator`]`
-#'  * Antonio J. Pérez-Luque  \href{https://orcid.org/0000-0002-1747-0469}{(ORCID)} `[`contributor, translator`]`
-#'  * Daniel Possenriede \href{https://orcid.org/0000-0002-6738-9845}{(ORCID)} `[`contributor, translator`]`
-#'  * Anatoly Tsyplenkov \href{https://orcid.org/0000-0003-4144-8402}{(ORCID)} `[`contributor, translator`]`
-#'  * Kaique dos S. Alves \href{https://orcid.org/0000-0001-9187-0252}{(ORCID)} `[`reviewer`]`
-#'  * Al-Ahmadgaid B. Asaad  \href{https://orcid.org/0000-0003-3784-8593}{(ORCID)} `[`reviewer`]`
-#'
 #' @seealso
 #' Useful links:
 #' * \url{https://docs.ropensci.org/datefixR/}
@@ -37,4 +24,5 @@
 ## usethis namespace: end
 #' @docType package
 #' @name datefixR
-NULL
+#' @keywords internal
+"_PACKAGE"
